Welcome to Tornamona's documentation!
======================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   readme.md
   tornamona/tornamona
   installation
   usage
   contributing
   authors
   history



Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
